==> cscec5b-xell-impl-3.0.1-20240315.030900-73-sources.jar: com/ejianc/business/wzxt/controller/StandingBookController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ProjectWbsEntity;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.ICauseService;
import com.ejianc.business.wzxt.service.IProjectWbsService;
import com.ejianc.business.wzxt.service.IReviewDetailService;
import com.ejianc.business.wzxt.vo.*;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;

/**
 * 限额领料台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("standingBook")
public class StandingBookController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IOrgApi orgApi;
    @Autowired
    private IReviewDetailService reviewDetailService;
    @Autowired
    private ICauseService causeService;
    @Autowired
    private IProjectWbsService projectWbsService;


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("spec");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Parameter wbsPara = param.getParams().get("wbsId");
        if(null != wbsPara){
            String wbsId = String.valueOf(wbsPara.getValue());
            List<ProjectWbsEntity> wbsEntities = projectWbsService.getChildrenByPid(Long.valueOf(wbsId));
            List<Long> wbsList = wbsEntities.stream().map(ProjectWbsEntity::getId).collect(Collectors.toList());
            param.getParams().put("wbsId", new Parameter(QueryParam.IN, wbsList));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryStandingBook(page, wrapper);
        for(int i = 0;i < list.size(); i++){
            list.get(i).setId((long)i);
        }
        param.getParams().remove("wbsId");
        wrapper = changeToQueryWrapper(param);
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            fullInfo(vo);
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }

        JSONObject res = new JSONObject();
        res.put("records", list);
        res.put("total", page.getTotal());
        res.put("current", page.getCurrent());
        res.put("size", page.getSize());
        res.put("pages", page.getPages());
        return CommonResponse.success("查询列表数据成功！", res);
    }

    private void fullInfo(CauseDetailVO vo) {
        List<PlanVO> planVOS = reviewDetailService.queryPlanInfo(vo.getProjectId(), vo.getWbsId(), vo.getMaterialId());
        Set<String> planEmpSet = new HashSet<>();
        Set<String> planTimeSet = new HashSet<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        for(PlanVO planVO : planVOS){
            planEmpSet.add(planVO.getEmployeeName());
            planTimeSet.add(sdf.format(planVO.getPlanDate()));
        }
        vo.setPlanEmployeeName(StringUtils.join(planEmpSet, ","));
        vo.setPlanTime(StringUtils.join(planTimeSet, ","));

        List<CheckVO> checkVOS = reviewDetailService.queryCheckInfo(vo.getProjectId(), vo.getWbsId(), vo.getMaterialId());
        if (CollectionUtils.isNotEmpty(checkVOS)) {
            vo.setCheckTime(sdf.format(checkVOS.get(0).getCheckDate()));
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        param.setPageIndex(1);
        param.setPageSize(-1);

        CommonResponse<JSONObject> commonResponse = queryList(param);

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", commonResponse.getData().get("records"));
        ExcelExport.getInstance().export("StandingBook-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refCauseData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CauseVO>> refCauseData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewDetailEntity> page = reviewDetailService.queryPage(param,false);
        IPage<CauseVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CauseVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> cscec5b-xell-impl-3.0.1-20250407.033944-86-sources.jar: com/ejianc/business/wzxt/controller/StandingBookController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ProjectWbsEntity;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.ICauseService;
import com.ejianc.business.wzxt.service.IProjectWbsService;
import com.ejianc.business.wzxt.service.IReviewDetailService;
import com.ejianc.business.wzxt.vo.*;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;

/**
 * 限额领料台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("standingBook")
public class StandingBookController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IOrgApi orgApi;
    @Autowired
    private IReviewDetailService reviewDetailService;
    @Autowired
    private ICauseService causeService;
    @Autowired
    private IProjectWbsService projectWbsService;


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("spec");
        fuzzyFields.add("materialName");
        fuzzyFields.add("dutyPersonDetailName");
        fuzzyFields.add("planEmployeeName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Parameter wbsPara = param.getParams().get("wbsId");
        if(null != wbsPara){
            String wbsId = String.valueOf(wbsPara.getValue());
            List<ProjectWbsEntity> wbsEntities = projectWbsService.getChildrenByPid(Long.valueOf(wbsId));
            List<Long> wbsList = wbsEntities.stream().map(ProjectWbsEntity::getId).collect(Collectors.toList());
            param.getParams().put("wbsId", new Parameter(QueryParam.IN, wbsList));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryReportList(page, wrapper);
        for(int i = 0;i < list.size(); i++){
            list.get(i).setId((long)i);
        }

        /*List<CauseDetailVO> list = reviewDetailService.queryStandingBook(page, wrapper);
        for(int i = 0;i < list.size(); i++){
            list.get(i).setId((long)i);
        }
        param.getParams().remove("wbsId");
        wrapper = changeToQueryWrapper(param);
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            fullInfo(vo);
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }*/

        JSONObject res = new JSONObject();
        res.put("records", list);
        res.put("total", page.getTotal());
        res.put("current", page.getCurrent());
        res.put("size", page.getSize());
        res.put("pages", page.getPages());
        return CommonResponse.success("查询列表数据成功！", res);
    }

    private void fullInfo(CauseDetailVO vo) {
        List<PlanVO> planVOS = reviewDetailService.queryPlanInfo(vo.getProjectId(), vo.getWbsId(), vo.getMaterialId());
        Set<String> planEmpSet = new HashSet<>();
        Set<String> planTimeSet = new HashSet<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        for(PlanVO planVO : planVOS){
            planEmpSet.add(planVO.getEmployeeName());
            planTimeSet.add(sdf.format(planVO.getPlanDate()));
        }
        vo.setPlanEmployeeName(StringUtils.join(planEmpSet, ","));
        vo.setPlanTime(StringUtils.join(planTimeSet, ","));

        List<CheckVO> checkVOS = reviewDetailService.queryCheckInfo(vo.getProjectId(), vo.getWbsId(), vo.getMaterialId());
        if (CollectionUtils.isNotEmpty(checkVOS)) {
            vo.setCheckTime(sdf.format(checkVOS.get(0).getCheckDate()));
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        param.setPageIndex(1);
        param.setPageSize(-1);

        CommonResponse<JSONObject> commonResponse = queryList(param);

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", commonResponse.getData().get("records"));
        ExcelExport.getInstance().export("StandingBook-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refCauseData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CauseVO>> refCauseData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewDetailEntity> page = reviewDetailService.queryPage(param,false);
        IPage<CauseVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CauseVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description queryProjectReport 报表查询
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryProjectReport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryProjectReport(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("parentOrgName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryProjectReport(page, wrapper);
        if (CollectionUtils.isNotEmpty(list)) {
            Set<Long> longSet = list.stream().map(CauseDetailVO::getParentOrgId).collect(Collectors.toSet());
            CommonResponse<List<OrgVO>> response = orgApi.findAllByIds(new ArrayList<>(longSet));
            if (response.isSuccess() && CollectionUtils.isNotEmpty(response.getData())) {
                Map<Long, String> map = response.getData().stream().collect(Collectors.toMap(OrgVO::getId, OrgVO::getName, (k1, k2) -> k1));
                for (CauseDetailVO detailVO : list) {
                    detailVO.setParentOrgName(map.get(detailVO.getParentOrgId()));
                }
            }
        }
        JSONObject res = new JSONObject();
        res.put("records", list);
        res.put("total", page.getTotal());
        res.put("current", page.getCurrent());
        res.put("size", page.getSize());
        res.put("pages", page.getPages());
        return CommonResponse.success("查询列表数据成功！", res);
    }

    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExportReport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExportReport(@RequestBody QueryParam param, HttpServletResponse response) {
        param.setPageIndex(1);
        param.setPageSize(-1);

        CommonResponse<JSONObject> commonResponse = queryProjectReport(param);

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", commonResponse.getData().get("records"));
        ExcelExport.getInstance().export("StandingBookReport-export.xlsx", beans, response);
    }
}
